//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[TileType](index.md)

# TileType

[common]\
enum [TileType](index.md) : [Enum](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-enum/index.html)&lt;[TileType](index.md)&gt; 

麻将牌的种类（万、筒、索、字）

## Entries

| | |
|---|---|
| [M](-m/index.md) | [common]<br>[M](-m/index.md)<br>万 |
| [P](-p/index.md) | [common]<br>[P](-p/index.md)<br>筒 |
| [S](-s/index.md) | [common]<br>[S](-s/index.md)<br>索 |
| [Z](-z/index.md) | [common]<br>[Z](-z/index.md)<br>字 |

## Types

| Name | Summary |
|---|---|
| [Companion](-companion/index.md) | [common]<br>object [Companion](-companion/index.md) |

## Properties

| Name | Summary |
|---|---|
| [entries](entries.md) | [common]<br>val [entries](entries.md): [EnumEntries](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.enums/-enum-entries/index.html)&lt;[TileType](index.md)&gt;<br>Returns a representation of an immutable list of all enum entries, in the order they're declared. |
| [name](../-wind/-north/index.md#-372974862%2FProperties%2F1581026887) | [common]<br>val [name](../-wind/-north/index.md#-372974862%2FProperties%2F1581026887): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../-wind/-north/index.md#-739389684%2FProperties%2F1581026887) | [common]<br>val [ordinal](../-wind/-north/index.md#-739389684%2FProperties%2F1581026887): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

## Functions

| Name | Summary |
|---|---|
| [valueOf](value-of.md) | [common]<br>fun [valueOf](value-of.md)(value: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [TileType](index.md)<br>Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.) |
| [values](values.md) | [common]<br>fun [values](values.md)(): [Array](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-array/index.html)&lt;[TileType](index.md)&gt;<br>Returns an array containing the constants of this enum type, in the order they're declared. |
